@@ -11,7 +11,7 @@ use File::HomeDir::Unix ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.82';
+	$VERSION = '0.84';
 	@ISA     = 'File::HomeDir::Unix';
 }
 
@@ -31,7 +31,15 @@ SCOPE: {
 
 sub my_home {
 	my ($class) = @_;
-	require Mac::Files;
+
+	# A lot of unix people and unix-derived tools rely on
+	# the ability to overload HOME. We will support it too
+	# so that they can replace raw HOME calls with File::HomeDir.
+	if ( exists $ENV{HOME} and defined $ENV{HOME} ) {
+		return $ENV{HOME};
+	}
+	
+  require Mac::Files;
 	$class->_find_folder(
 		Mac::Files::kCurrentUserFolderType(),
 		);
@@ -112,7 +120,7 @@ sub _find_folder {
 sub users_home {
 	my $class = shift;
 	my $home  = $class->SUPER::users_home(@_);
-	return Cwd::abs_path($home);
+	return defined $home ? Cwd::abs_path($home) : undef;
 }
 
 # in theory this can be done, but for now, let's cheat, since the
@@ -141,7 +149,8 @@ sub _to_user {
 	my ($class, $path, $name) = @_;
 	my $my_home    = $class->my_home;
 	my $users_home = $class->users_home($name);
-	$path =~ s/^Q$my_home/$users_home/;
+	defined $users_home or return undef;
+	$path =~ s/^\Q$my_home/$users_home/;
 	return $path;
 }
 
